@@ -176,7 +176,7 @@ postgres_password=$(tr -dc 'A-Za-z0-9!?&()-+=' </dev/urandom | head -c 18)
 # Create PostgreSQL data directory
 mkdir -p /docker/postgresql
 # Start PostgreSQL (bind to localhost for host access, accessible via container name within Docker network)
-docker run -d --network client-net --name postgresql --env POSTGRES_PASSWORD="$postgres_password" -v /docker/postgresql:/var/lib/postgresql/data:Z -p 127.0.0.1:5432:5432 --restart unless-stopped postgres:latest
+docker run -d --network client-net --name postgresql --env POSTGRES_PASSWORD="$postgres_password" -v /docker/postgresql:/var/lib/postgresql:Z -p 127.0.0.1:5432:5432 --restart unless-stopped postgres:latest
 # Store PostgreSQL login details in .pgpass format (use localhost for host-based connections)
 echo "127.0.0.1:5432:*:postgres:$postgres_password" > /root/.pgpass
 chmod 600 /root/.pgpass
