@@ -255,7 +255,16 @@ try {
             ob_clean(); // Clear buffer before output
             echo json_encode($result);
             exit;
-            
+
+        case 'force_https':
+            if (empty($_POST['site_id']) || !is_numeric($_POST['site_id'])) {
+                throw new Exception('Valid numeric site ID required');
+            }
+            $result = $wpManager->forceHttps((int)$_POST['site_id']);
+            ob_clean(); // Clear buffer before output
+            echo json_encode($result);
+            exit;
+
         case 'security_scan':
             if (empty($_POST['site_id'])) {
                 throw new Exception('Site ID required');
