@@ -161,28 +161,16 @@ if (!array_key_exists($page, $allowed_pages)) {
                 
                 <!-- User Dropdown -->
                 <div class="navbar-nav ms-auto">
-                    <!-- Theme Toggle Switch -->
+                    <!-- Theme Toggle Button -->
                     <div class="font-size-toggle-wrapper">
-                        <label class="font-size-toggle-label" for="themeToggle">
-                            <span class="font-size-icons">
-                                <i class="fa fa-sun-o" id="lightThemeIcon"></i>
-                                <i class="fa fa-moon-o" id="darkThemeIcon"></i>
-                            </span>
-                            <div class="toggle-switch" title="Toggle light/dark theme">
-                                <input type="checkbox"
-                                       id="themeToggle"
-                                       <?php
-                                       $theme_pref = $_SESSION['theme_preference'] ?? 'auto';
-                                       // If theme is light or auto (detected as light), check the toggle
-                                       echo ($theme_pref === 'dark') ? '' : 'checked';
-                                       ?>
-                                       aria-label="Toggle light/dark theme"
-                                       aria-describedby="themeToggleDescription"
-                                       role="switch">
-                                <span class="toggle-slider"></span>
-                            </div>
-                            <span class="visually-hidden" id="themeToggleDescription">Toggle between light and dark theme</span>
-                        </label>
+                        <button id="themeToggleBtn"
+                                class="btn btn-sm btn-outline-light me-2"
+                                data-theme-pref="<?php echo htmlspecialchars($_SESSION['theme_preference'] ?? 'auto'); ?>"
+                                title="Theme: Auto (follows system)"
+                                aria-label="Toggle theme (Auto/Light/Dark)">
+                            <i class="fa fa-adjust"></i>
+                            <span id="themeLabel" class="ms-1">Auto</span>
+                        </button>
                     </div>
 
                     <!-- Font Size Toggle Switch -->
@@ -463,45 +451,60 @@ if (!array_key_exists($page, $allowed_pages)) {
                 });
             }
 
-            // Theme Toggle Functionality
-            const themeToggle = document.getElementById('themeToggle');
-            if (themeToggle) {
+            // Theme Toggle Functionality (3-state: auto/light/dark)
+            const themeToggleBtn = document.getElementById('themeToggleBtn');
+            const themeLabel = document.getElementById('themeLabel');
+
+            if (themeToggleBtn) {
+                // Theme configuration
+                const themeConfig = {
+                    'auto': { icon: 'fa-adjust', label: 'Auto', title: 'Theme: Auto (follows system)', next: 'light' },
+                    'light': { icon: 'fa-sun-o', label: 'Light', title: 'Theme: Light', next: 'dark' },
+                    'dark': { icon: 'fa-moon-o', label: 'Dark', title: 'Theme: Dark', next: 'auto' }
+                };
+
+                let currentPref = themeToggleBtn.getAttribute('data-theme-pref') || 'auto';
+
                 // Function to apply theme
-                function applyTheme(theme) {
+                function applyTheme(themePref) {
                     const html = document.documentElement;
+                    let actualTheme = themePref;
 
                     // Handle auto theme - detect system preference
-                    if (theme === 'auto') {
+                    if (themePref === 'auto') {
                         const prefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches;
-                        theme = prefersDark ? 'dark' : 'light';
+                        actualTheme = prefersDark ? 'dark' : 'light';
                     }
 
                     // Apply theme attribute
-                    html.setAttribute('data-theme', theme);
+                    html.setAttribute('data-theme', actualTheme);
 
-                    // Update toggle state (checked = light, unchecked = dark)
-                    themeToggle.checked = (theme === 'light');
+                    // Update button appearance
+                    const config = themeConfig[themePref];
+                    const iconElement = themeToggleBtn.querySelector('i');
+                    iconElement.className = 'fa ' + config.icon;
+                    themeLabel.textContent = config.label;
+                    themeToggleBtn.title = config.title;
+                    themeToggleBtn.setAttribute('data-theme-pref', themePref);
+                    currentPref = themePref;
                 }
 
                 // Apply initial theme on page load
-                const initialTheme = document.documentElement.getAttribute('data-theme') || 'dark';
-                applyTheme(initialTheme);
+                applyTheme(currentPref);
 
                 // Listen for system theme changes if using auto mode
                 window.matchMedia('(prefers-color-scheme: dark)').addEventListener('change', (e) => {
-                    const currentPref = '<?php echo $_SESSION['theme_preference'] ?? 'auto'; ?>';
                     if (currentPref === 'auto') {
                         applyTheme('auto');
                     }
                 });
 
-                // Handle toggle change
-                themeToggle.addEventListener('change', function() {
-                    const isLight = this.checked;
-                    const newTheme = isLight ? 'light' : 'dark';
+                // Handle button click - cycle through themes
+                themeToggleBtn.addEventListener('click', function() {
+                    const nextTheme = themeConfig[currentPref].next;
 
                     // Apply theme immediately for smooth transition
-                    document.documentElement.setAttribute('data-theme', newTheme);
+                    applyTheme(nextTheme);
 
                     // Send AJAX request to save preference
                     fetch('api/theme-toggle.php', {
@@ -510,32 +513,25 @@ if (!array_key_exists($page, $allowed_pages)) {
                             'Content-Type': 'application/x-www-form-urlencoded',
                             'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
                         },
-                        body: 'action=set&theme=' + newTheme
+                        body: 'action=set&theme=' + encodeURIComponent(nextTheme)
                     })
                     .then(response => response.json())
                     .then(data => {
                         if (data.success) {
-                            // Update aria-checked for screen readers
-                            themeToggle.setAttribute('aria-checked', isLight ? 'true' : 'false');
-
                             // Announce change to screen readers
                             const announcement = document.createElement('div');
                             announcement.setAttribute('role', 'status');
                             announcement.setAttribute('aria-live', 'polite');
                             announcement.className = 'visually-hidden';
-                            announcement.textContent = isLight ? 'Light theme enabled' : 'Dark theme enabled';
+                            announcement.textContent = 'Theme changed to ' + themeConfig[nextTheme].label;
                             document.body.appendChild(announcement);
                             setTimeout(() => announcement.remove(), 1000);
                         } else {
-                            // Revert on error
-                            applyTheme(newTheme === 'light' ? 'dark' : 'light');
                             console.error('Failed to save theme preference:', data.error);
                         }
                     })
                     .catch(error => {
                         console.error('Error toggling theme:', error);
-                        // Revert on error
-                        applyTheme(newTheme === 'light' ? 'dark' : 'light');
                     });
                 });
             }
